@@ -1,28 +1,15 @@
 /*
-   This file is part of the KDE project
+    This file is part of the KDE project
 
-   Copyright (C) 2007 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kfiletreeview_p.h"
 
-#include <QDir>
 #include <QContextMenuEvent>
+#include <QDir>
 #include <QMenu>
 #include <QUrl>
 
@@ -43,9 +30,9 @@ public:
 
     QUrl urlForProxyIndex(const QModelIndex &index) const;
 
-    void _k_activated(const QModelIndex &);
-    void _k_currentChanged(const QModelIndex &, const QModelIndex &);
-    void _k_expanded(const QModelIndex &);
+    void activated(const QModelIndex &);
+    void currentChanged(const QModelIndex &, const QModelIndex &);
+    void expanded(const QModelIndex &);
 
     KFileTreeView *const q;
     KDirModel *mSourceModel = nullptr;
@@ -59,7 +46,7 @@ QUrl KFileTreeView::Private::urlForProxyIndex(const QModelIndex &index) const
     return !item.isNull() ? item.url() : QUrl();
 }
 
-void KFileTreeView::Private::_k_activated(const QModelIndex &index)
+void KFileTreeView::Private::activated(const QModelIndex &index)
 {
     const QUrl url = urlForProxyIndex(index);
     if (url.isValid()) {
@@ -67,15 +54,15 @@ void KFileTreeView::Private::_k_activated(const QModelIndex &index)
     }
 }
 
-void KFileTreeView::Private::_k_currentChanged(const QModelIndex &currentIndex, const QModelIndex &)
+void KFileTreeView::Private::currentChanged(const QModelIndex &currentIndex, const QModelIndex &)
 {
     const QUrl url = urlForProxyIndex(currentIndex);
     if (url.isValid()) {
-        Q_EMIT q->currentChanged(url);
+        Q_EMIT q->currentUrlChanged(url);
     }
 }
 
-void KFileTreeView::Private::_k_expanded(const QModelIndex &baseIndex)
+void KFileTreeView::Private::expanded(const QModelIndex &baseIndex)
 {
     QModelIndex index = mProxyModel->mapFromSource(baseIndex);
 
@@ -86,7 +73,8 @@ void KFileTreeView::Private::_k_expanded(const QModelIndex &baseIndex)
 }
 
 KFileTreeView::KFileTreeView(QWidget *parent)
-    : QTreeView(parent), d(new Private(this))
+    : QTreeView(parent)
+    , d(new Private(this))
 {
     d->mSourceModel = new KDirModel(this);
     d->mProxyModel = new KDirSortFilterProxyModel(this);
@@ -98,13 +86,17 @@ KFileTreeView::KFileTreeView(QWidget *parent)
 
     d->mSourceModel->dirLister()->openUrl(QUrl::fromLocalFile(QDir::root().absolutePath()), KDirLister::Keep);
 
-    connect(this, SIGNAL(activated(QModelIndex)),
-            this, SLOT(_k_activated(QModelIndex)));
-    connect(selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(_k_currentChanged(QModelIndex,QModelIndex)));
+    connect(this, &QAbstractItemView::activated, this, [this](const QModelIndex &index) {
+        d->activated(index);
+    });
 
-    connect(d->mSourceModel, SIGNAL(expand(QModelIndex)),
-            this, SLOT(_k_expanded(QModelIndex)));
+    connect(selectionModel(), &QItemSelectionModel::currentChanged, this, [this](const QModelIndex &current, const QModelIndex &previous) {
+        d->currentChanged(current, previous);
+    });
+
+    connect(d->mSourceModel, &KDirModel::expand, this, [this](const QModelIndex &index) {
+        d->expanded(index);
+    });
 }
 
 KFileTreeView::~KFileTreeView()
@@ -210,4 +202,3 @@ QSize KFileTreeView::sizeHint() const
 }
 
 #include "moc_kfiletreeview_p.cpp"
-
